@@ -310,14 +310,6 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "Falklandsoyggjar t\u00ed\u00f0",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Butan t\u00ed\u00f0",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia vanlig t\u00ed\u00f0",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "Apia t\u00ed\u00f0",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Butan t\u00ed\u00f0",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru t\u00ed\u00f0",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolombia vanlig t\u00ed\u00f0",
+        final String[] Australia_Eastern = new String[] {
+               "eystur Avstralia vanlig t\u00ed\u00f0",
                "",
-               "Kolombia summart\u00ed\u00f0",
+               "eystur Avstralia summart\u00ed\u00f0",
                "",
-               "Kolombia t\u00ed\u00f0",
+               "eystur Avstralia t\u00ed\u00f0",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "eystur Avstralia vanlig t\u00ed\u00f0",
+        final String[] Colombia = new String[] {
+               "Kolombia vanlig t\u00ed\u00f0",
                "",
-               "eystur Avstralia summart\u00ed\u00f0",
+               "Kolombia summart\u00ed\u00f0",
                "",
-               "eystur Avstralia t\u00ed\u00f0",
+               "Kolombia t\u00ed\u00f0",
                "",
             };
         final String[] Chile = new String[] {
@@ -1038,14 +1038,6 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Northwest Mexico vanlig t\u00ed\u00f0",
-               "",
-               "Northwest Mexico summart\u00ed\u00f0",
-               "",
-               "Northwest Mexico t\u00ed\u00f0",
-               "",
-            };
         final String[] Easter = new String[] {
                "P\u00e1skaoyggin vanlig t\u00ed\u00f0",
                "",
@@ -1054,6 +1046,14 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
                "P\u00e1skaoyggin t\u00ed\u00f0",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Northwest Mexico vanlig t\u00ed\u00f0",
+               "",
+               "Northwest Mexico summart\u00ed\u00f0",
+               "",
+               "Northwest Mexico t\u00ed\u00f0",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville t\u00ed\u00f0",
                "",
@@ -1309,7 +1309,6 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1638,7 +1637,6 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1870,7 +1868,6 @@ public class TimeZoneNames_fo extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Aten" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
